parse_template

Function parse_template 

pub fn parse_template(
    xml: &str,
    datasets_xml: Option<&str>,
) -> Result<(FormTree, FormNodeId)>
Parse a <template> XML packet into a FormTree.

xml should be the raw content of the template packet, starting with the <template …> element (with or without an XML declaration).

If datasets_xml is provided, field values are merged from the <xfa:data> section of the datasets packet.